@@ -1108,14 +1108,6 @@ impl RTPDTMFSrc {
 
         Ok(())
     }
-
-    fn pause(&self) -> Result<(), gst::ErrorMessage> {
-        gst::debug!(CAT, imp = self, "Pausing");
-        self.task.pause().block_on()?;
-        gst::debug!(CAT, imp = self, "Paused");
-
-        Ok(())
-    }
 }
 
 #[glib::object_subclass]
@@ -1346,8 +1338,8 @@ impl ElementImpl for RTPDTMFSrc {
                     gst::StateChangeError
                 })?;
             }
-            gst::StateChange::PlayingToPaused => {
-                self.pause().map_err(|_| gst::StateChangeError)?;
+            gst::StateChange::PausedToReady => {
+                self.stop().map_err(|_| gst::StateChangeError)?;
             }
             gst::StateChange::ReadyToNull => {
                 self.unprepare();
@@ -1359,7 +1351,6 @@ impl ElementImpl for RTPDTMFSrc {
 
         match transition {
             gst::StateChange::ReadyToPaused => {
-                self.pause().map_err(|_| gst::StateChangeError)?;
                 success = gst::StateChangeSuccess::NoPreroll;
             }
             gst::StateChange::PausedToPlaying => {
@@ -1368,9 +1359,6 @@ impl ElementImpl for RTPDTMFSrc {
             gst::StateChange::PlayingToPaused => {
                 success = gst::StateChangeSuccess::NoPreroll;
             }
-            gst::StateChange::PausedToReady => {
-                self.stop().map_err(|_| gst::StateChangeError)?;
-            }
             _ => (),
         }
 
